# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic.v1 import BaseModel, Field, StrictStr

class Function(BaseModel):
    """
    An OpenAI API compatible schema for function which can be called.  # noqa: E501
    """
    name: StrictStr = Field(...)
    description: StrictStr = Field(...)
    parameters: Optional[Any] = None
    __properties = ["name", "description", "parameters"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Function:
        """Create an instance of Function from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if parameters (nullable) is None
        # and __fields_set__ contains the field
        if self.parameters is None and "parameters" in self.__fields_set__:
            _dict['parameters'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Function:
        """Create an instance of Function from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Function.parse_obj(obj)

        _obj = Function.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "parameters": obj.get("parameters")
        })
        return _obj





# coding: utf-8

"""
    asset-lake-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic.v1 import BaseModel, Field
from clients.asset_lake.models.asset import Asset
from clients.asset_lake.models.transfer_api1 import TransferApi1

class RetrieveAssetResponse(BaseModel):
    """
    RetrieveAssetResponse
    """
    asset: Asset = Field(...)
    transfer_api: TransferApi1 = Field(...)
    __properties = ["asset", "transfer_api"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RetrieveAssetResponse:
        """Create an instance of RetrieveAssetResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transfer_api
        if self.transfer_api:
            _dict['transfer_api'] = self.transfer_api.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RetrieveAssetResponse:
        """Create an instance of RetrieveAssetResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RetrieveAssetResponse.parse_obj(obj)

        _obj = RetrieveAssetResponse.parse_obj({
            "asset": Asset.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "transfer_api": TransferApi1.from_dict(obj.get("transfer_api")) if obj.get("transfer_api") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from clients.fine_tuning.api.tune_api import TuneApi

# import ApiClient
from clients.fine_tuning.api_response import ApiResponse
from clients.fine_tuning.api_client import ApiClient
from clients.fine_tuning.configuration import Configuration
from clients.fine_tuning.exceptions import OpenApiException
from clients.fine_tuning.exceptions import ApiTypeError
from clients.fine_tuning.exceptions import ApiValueError
from clients.fine_tuning.exceptions import ApiKeyError
from clients.fine_tuning.exceptions import ApiAttributeError
from clients.fine_tuning.exceptions import ApiException

# import models into sdk package
from clients.fine_tuning.models.base_engine import BaseEngine
from clients.fine_tuning.models.create_tune_request import CreateTuneRequest
from clients.fine_tuning.models.details import Details
from clients.fine_tuning.models.details1 import Details1
from clients.fine_tuning.models.http_validation_error import HTTPValidationError
from clients.fine_tuning.models.list_tunes_response import ListTunesResponse
from clients.fine_tuning.models.location_inner import LocationInner
from clients.fine_tuning.models.lora_tune_checkpoint import LoraTuneCheckpoint
from clients.fine_tuning.models.lora_tune_file import LoraTuneFile
from clients.fine_tuning.models.lora_tune_input import LoraTuneInput
from clients.fine_tuning.models.lora_tune_output import LoraTuneOutput
from clients.fine_tuning.models.text_to_speech_latent_tune import TextToSpeechLatentTune
from clients.fine_tuning.models.tune import Tune
from clients.fine_tuning.models.tune_result import TuneResult
from clients.fine_tuning.models.tune_status import TuneStatus
from clients.fine_tuning.models.tune_type import TuneType
from clients.fine_tuning.models.validation_error import ValidationError
